capture log close
local date: di %d date(c(current_date),"DMY")
log using $log\TFP_estimation_`date'.log, replace
*-------------------------------------------------------------------------------
* LABOR PRODUCTIVITY AND ESTIMATION OF TOTAL FACTOR PRODUCTIVITY
*-------------------------------------------------------------------------------
cd "$main"
set more off
clear all
use "$data\panel_v4.dta", clear
xtset idnum year
drop if year==.

*-------------------------------------------------------------------------------				
* DEFLATION OF VARIABLES			
*-------------------------------------------------------------------------------	
sort idnum year
* import CPI deflation values for each year (yearly average) from DeStatis with base_year==2015: 
* Source: https://www-genesis.destatis.de/genesis/online 61111-0001	Verbraucherpreisindex (inkl. Veränderungsraten): Deutschland, Jahre
gen deflation_cpi =.
replace deflation_cpi=105.8 if year==2020 
replace deflation_cpi=105.3 if year==2019
replace deflation_cpi=103.8 if year==2018
replace deflation_cpi=102.0 if year==2017
replace deflation_cpi=100.5 if year==2016
replace deflation_cpi=100.0 if year==2015
replace deflation_cpi=99.5 if year==2014
replace deflation_cpi=98.5 if year==2013

*** DEFLATE BUSINESS VOLUME ***
sum business_vol
bys idnum year: replace business_vol=business_vol/(deflation_cpi/100)
label variable business_vol "business volume (deflated)"
sum business_vol
bys idnum year: gen log_busi_vol=log(business_vol)
label variable log_busi_vol "log business volume (deflated)"

*** DEFLATE Wage ***
sum wage_total
bys idnum year: replace wage_total=wage_total/(deflation_cpi/100)
label variable wage_total "wage total (deflated)"
sum wage_total
bys idnum year: gen log_wage_total=log(wage_total)
label variable log_wage_total "log wage total (deflated)"

*** DEFLATE Investment ***
sum invest
bys idnum year: replace invest=invest/(deflation_cpi/100)
label variable invest "investments (deflated)"
sum invest
bys idnum year: gen log_invest=log(invest)
label variable log_invest "log invest (deflated)"

*** DEFLATE expenditures (vorleis) ***
sum vorleis
bys idnum year: replace vorleis=vorleis/(deflation_cpi/100)
label variable vorleis "vorleis (deflated)"
sum vorleis
bys idnum year: gen log_vorleis=log(vorleis)
label variable log_vorleis "log vorleis (deflated)"

*** DEFLATE approx. capital stock (KTbp) ***
bys idnum year: replace KTbp=KTbp/(deflation_cpi/100)
label variable KTbp "approx. capital stock KTbp (deflated)"
sum KTbp


*-------------------------------------------------------------------------------
* LABOR PRODUCTIVITY
*-------------------------------------------------------------------------------
* calculate intermediate goods expenditures  // NOTE: deflation now here VP 18/07/2022 (previously later in indicators.do) 
	bys idnum year: gen expend= business_vol*vorleis/100 if vorleis!=.
	label var expend "intermediate good expenditures (deflated)"
	sum business_vol vorleis expend if year==2018
* calculate value added:
	bys idnum year: gen va=business_vol-expend
	bys idnum year: gen ln_va=log(business_vol-expend)
	sum *va if year==2018
	label var ln_va "log value added at plant level (deflated)"
	* possible assumption: even though investments etc are from previous period, we could assume that current number of robot stock is not too different. 
* calculate labor productivity value added based 
	bys idnum year: gen lprod=(business_vol-expend)/ges_bes
	bys idnum year: gen log_lprod =log(lprod)
	sum lprod log_lprod* va ln_va,d
	sum lprod log_lprod* if year==2014
	sum lprod log_lprod* if  D_robot_adoption!=.
	label var log_lprod  "log labor productivity (value added per emloyee) at plant level (deflated)"
	
* calculate labor productivity broad measure
	bys idnum year: gen lprod2=(business_vol)/ges_bes
    bys idnum year: gen log_lprod2 =log(lprod2)
	sum lprod2 log_lprod2 if year==2014
    label var log_lprod2  "log labor productivity 2 (business_vol per employee) at plant level"
	
* labour and capital in logs:
	bys idnum year: gen ln_capital=ln(KTbp)
	bys idnum year: gen ln_labour=ln(ges_bes)	
	bys idnum year: gen ln_expend=ln(expend)	


*-------------------------------------------------------------------------------
* TIME-VARYING COBB DOUGLAS (revenue based) 
*-------------------------------------------------------------------------------
* create variables to store elasticities 
gen el_exp_tv_cd = .
gen el_lab_tv_cd = .
gen el_cap_tv_cd = .


* Production Function Estimation
levelsof IAB_43, local(sectors)								
foreach sector of local sectors {
	quietly reg log_busi_vol c.ln_labour#i.year c.ln_capital#i.year c.ln_expend#i.year i.year i.IAB_43 i.bula if IAB_43 == `sector', vce(cluster idnum)
	
	matrix coeff = e(b) // store coefficients in matrix
	matrix list coeff
	local coefflist: colnames coeff // list of variable names
	levelsof year, local(years)
	foreach year of local years {	
		foreach var of local coefflist { 	
		if regexm("`var'", "`year'") { // falls year und mat | lab | kap in Variablennamen vorkommt, speichere Koeffizient als Elastizität	
				quietly replace el_exp_tv_cd = _b[`var'] if regexm("`var'", "ln_expend") & year == `year' & IAB_43 == `sector'
				quietly replace el_lab_tv_cd = _b[`var'] if regexm("`var'", "ln_labour") & year == `year' & IAB_43 == `sector'
				quietly replace el_cap_tv_cd = _b[`var'] if regexm("`var'", "ln_capital") & year == `year' & IAB_43 ==`sector'
			}
		}
	}
}

* calculate TFP
gen lntfp_tv_cd = log_busi_vol - el_lab_tv_cd * ln_labour - el_cap_tv_cd * ln_capital - el_exp_tv_cd * ln_expend
label variable lntfp_tv_cd "Log TFP (time varying Cobb-Douglas)"


save "$data/panel_v5.dta", replace

capture log close
